@@ -1,6 +1,6 @@
 package DBIx::Class::DeploymentHandler;
 {
-  $DBIx::Class::DeploymentHandler::VERSION = '0.002205';
+  $DBIx::Class::DeploymentHandler::VERSION = '0.002206';
 }
 
 # ABSTRACT: Extensible DBIx::Class deployment
@@ -66,7 +66,7 @@ __PACKAGE__->meta->make_immutable;
 
 #vim: ts=2 sw=2 expandtab
 
-
+__END__
 
 =pod
 
@@ -209,9 +209,11 @@ because I love it.
 
 Instead, consider donating to someone who might actually need it.  Obviously
 you should do research when donating to a charity, so don't just take my word
-on this.  I like Children's Survival Fund:
-L<http://www.childrenssurvivalfund.org>, but there are a host of other
+on this.  I like Matthew 25: Ministries:
+L<http://www.m25m.org/>, but there are a host of other
 charities that can do much more good than I will with your money.
+(Third party charity info here:
+L<http://www.charitynavigator.org/index.cfm?bay=search.summary&orgid=6901>
 
 =head1 METHODS
 
@@ -247,7 +249,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
